@@ -1,6 +1,6 @@
 # --
 # Kernel/GenericInterface/Transport/HTTP/SOAP.pm - GenericInterface network transport interface for HTTP::SOAP
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,8 +18,6 @@ use Kernel::System::VariableCheck qw(:all);
 use Encode;
 use PerlIO;
 
-use vars qw(@ISA);
-
 =head1 NAME
 
 Kernel::GenericInterface::Transport::SOAP - GenericInterface network transport interface for HTTP::SOAP
@@ -182,8 +180,12 @@ sub ProviderProcessRequest {
 
     # convert charset if necessary
     my $ContentCharset;
-    if ( $ENV{'CONTENT_TYPE'} =~ m{ \A .* charset= ["']? ( [^"']+ ) ["']? \z }xmsi ) {
-        $ContentCharset = $1;
+    if ( $ENV{'CONTENT_TYPE'} =~ m{ \A (.*) ;charset= ["']? ( [^"']+ ) ["']? \z }xmsi ) {
+
+        # remember content type for the response
+        $Self->{ContentType} = $1;
+
+        $ContentCharset = $2;
     }
     if ( $ContentCharset && $ContentCharset !~ m{ \A utf [-]? 8 \z }xmsi ) {
         $Content = $Self->{EncodeObject}->Convert2CharsetInternal(
@@ -341,9 +343,7 @@ sub ProviderGenerateResponse {
     if ($SOAPResult) {
         push @CallData, $SOAPResult;
     }
-    my $Serialized = SOAP::Serializer
-        ->autotype(0)
-        ->default_ns( $Self->{TransportConfig}->{Config}->{NameSpace} )
+    my $Serialized = SOAP::Serializer->autotype(0)->default_ns( $Self->{TransportConfig}->{Config}->{NameSpace} )
         ->envelope(@CallData);
     my $SerializedFault = $@ || '';
     if ($SerializedFault) {
@@ -444,9 +444,7 @@ sub RequesterPerformRequest {
     }
 
     # prepare method
-    my $SOAPMethod = SOAP::Data
-        ->name( $Param{Operation} )
-        ->uri( $Config->{NameSpace} );
+    my $SOAPMethod = SOAP::Data->name( $Param{Operation} )->uri( $Config->{NameSpace} );
     if ( ref $SOAPMethod ne 'SOAP::Data' ) {
         return {
             Success      => 0,
@@ -521,13 +519,10 @@ sub RequesterPerformRequest {
 
     # prepare connect
     my $SOAPHandle = eval {
-        SOAP::Lite
-            ->autotype(0)
-            ->default_ns( $Config->{NameSpace} )
-            ->proxy(
+        SOAP::Lite->autotype(0)->default_ns( $Config->{NameSpace} )->proxy(
             $URL,
             timeout => 60,
-            );
+        );
     };
     my $SOAPHandleFault = $@ || '';
     if ($SOAPHandleFault) {
@@ -602,8 +597,7 @@ sub RequesterPerformRequest {
             ErrorMessage => 'SOAP Transport: Could not get xml data sent to remote system',
         };
     }
-    my $XMLRequest
-        = $SOAPResult->context()->transport()->proxy()->http_response()->request()->content();
+    my $XMLRequest = $SOAPResult->context()->transport()->proxy()->http_response()->request()->content();
     $Self->{EncodeObject}->EncodeInput( \$XMLRequest );
     $Self->{DebuggerObject}->Debug(
         Summary => 'Xml data sent to remote system',
@@ -678,7 +672,7 @@ sub RequesterPerformRequest {
     # all ok - return result
     return {
         Success => 1,
-        Data => $Body->{ $Param{Operation} . 'Response' } || undef,
+        Data    => $Body->{ $Param{Operation} . 'Response' } || undef,
     };
 }
 
@@ -782,7 +776,10 @@ sub _Output {
     $Param{HTTPCode} ||= 500;
     my $ContentType;
     if ( $Param{HTTPCode} eq 200 ) {
-        $ContentType = 'text/xml';
+        $ContentType = 'application/soap+xml';
+        if ( $Self->{ContentType} ) {
+            $ContentType = $Self->{ContentType};
+        }
     }
     else {
         $ContentType = 'text/plain';
