@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketCustomer.pm - to set the ticket customer and show the customer history
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketCustomer.pm,v 1.42 2012-01-24 00:08:45 cr Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +15,6 @@ use warnings;
 use Kernel::System::CustomerUser;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.42 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -103,7 +98,7 @@ sub Run {
     );
     my %AclAction = $Self->{TicketObject}->TicketAclActionData();
 
-    # check if ACL resctictions if exist
+    # check if ACL restrictions exist
     if ( IsHashRefWithData( \%AclAction ) ) {
 
         # show error screen if ACL prohibits this action
@@ -124,13 +119,12 @@ sub Run {
             || 0;
         my $CustomerUserOption = $Self->{ParamObject}->GetParam( Param => 'CustomerUserOption' )
             || '';
-        $Param{CustomerUserID} = $Self->{ParamObject}->GetParam( Param => 'CustomerUserID' ) || '';
-        $Param{CustomerID}     = $Self->{ParamObject}->GetParam( Param => 'CustomerID' )     || '';
-        $Param{SelectedCustomerUser}
-            = $Self->{ParamObject}->GetParam( Param => 'SelectedCustomerUser' ) || '';
+        $Param{CustomerUserID}       = $Self->{ParamObject}->GetParam( Param => 'CustomerUserID' )       || '';
+        $Param{CustomerID}           = $Self->{ParamObject}->GetParam( Param => 'CustomerID' )           || '';
+        $Param{SelectedCustomerUser} = $Self->{ParamObject}->GetParam( Param => 'SelectedCustomerUser' ) || '';
 
         # use customer login instead of email address if applicable
-        if ( $Param{SelectedCustomerUser} ne q{} ) {
+        if ( $Param{SelectedCustomerUser} ne '' ) {
             $Param{CustomerUserID} = $Param{SelectedCustomerUser};
         }
 
@@ -139,13 +133,14 @@ sub Run {
 
             # search customer
             my %CustomerUserList = ();
-            %CustomerUserList
-                = $Self->{CustomerUserObject}->CustomerSearch( Search => $Param{CustomerUserID}, );
+            %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
+                Search => $Param{CustomerUserID},
+            );
 
             # check if just one customer user exists
             # if just one, fillup CustomerUserID and CustomerID
             $Param{CustomerUserListCount} = 0;
-            for my $KeyCustomerUser ( keys %CustomerUserList ) {
+            for my $KeyCustomerUser ( sort keys %CustomerUserList ) {
                 $Param{CustomerUserListCount}++;
                 $Param{CustomerUserListLast}     = $CustomerUserList{$KeyCustomerUser};
                 $Param{CustomerUserListLastUser} = $KeyCustomerUser;
@@ -172,11 +167,13 @@ sub Run {
 
         # get customer user and customer id
         elsif ($ExpandCustomerName2) {
-            my %CustomerUserData
-                = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $CustomerUserOption, );
-            my %CustomerUserList
-                = $Self->{CustomerUserObject}->CustomerSearch( UserLogin => $CustomerUserOption, );
-            for my $KeyCustomerUser ( keys %CustomerUserList ) {
+            my %CustomerUserData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                User => $CustomerUserOption,
+            );
+            my %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
+                UserLogin => $CustomerUserOption,
+            );
+            for my $KeyCustomerUser ( sort keys %CustomerUserList ) {
                 $Param{CustomerUserID} = $KeyCustomerUser;
             }
             if ( $CustomerUserData{UserCustomerID} ) {
@@ -212,9 +209,7 @@ sub Run {
 
             # redirect
             return $Self->{LayoutObject}->PopupClose(
-                URL =>
-                    $Self->{LastScreenView}
-                    || "Action=AgentTicketZoom;TicketID=$Self->{TicketID}",
+                URL => "Action=AgentTicketZoom;TicketID=$Self->{TicketID}",
             );
         }
         else {
@@ -235,10 +230,6 @@ sub Form {
 
     my $Output;
 
-    # get autocomplete config
-    my $AutoCompleteConfig
-        = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerSearchAutoComplete');
-
     # print header
     $Output .= $Self->{LayoutObject}->Header(
         Type => 'Small',
@@ -252,24 +243,18 @@ sub Form {
         # set some customer search autocomplete properties
         $Self->{LayoutObject}->Block(
             Name => 'CustomerSearchAutoComplete',
-            Data => {
-                minQueryLength      => $AutoCompleteConfig->{MinQueryLength}      || 2,
-                queryDelay          => $AutoCompleteConfig->{QueryDelay}          || 100,
-                maxResultsDisplayed => $AutoCompleteConfig->{MaxResultsDisplayed} || 20,
-                ActiveAutoComplete  => $AutoCompleteConfig->{Active},
-            },
         );
 
         # get ticket data
         my %TicketData = $Self->{TicketObject}->TicketGet( TicketID => $Self->{TicketID} );
         if ( $TicketData{CustomerUserID} || $Param{CustomerUserID} ) {
-            %CustomerUserData
-                = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                User => $Param{CustomerUserID}
-                    || $TicketData{CustomerUserID},
-                );
+            %CustomerUserData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                User => $Param{CustomerUserID} || $TicketData{CustomerUserID},
+            );
         }
         $TicketCustomerID = $TicketData{CustomerID};
+        $Param{SelectedCustomerUser} = $TicketData{CustomerUserID};
+
         $Param{Table} = $Self->{LayoutObject}->AgentCustomerViewTable(
             Data => \%CustomerUserData,
             Max  => $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerInfoComposeMaxSize'),
@@ -287,7 +272,10 @@ sub Form {
     }
 
     $Output
-        .= $Self->{LayoutObject}->Output( TemplateFile => 'AgentTicketCustomer', Data => \%Param );
+        .= $Self->{LayoutObject}->Output(
+        TemplateFile => 'AgentTicketCustomer',
+        Data         => \%Param
+        );
     $Output .= $Self->{LayoutObject}->Footer(
         Type => 'Small',
     );
