@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -267,7 +267,7 @@ sub Run {
                     Type                   => $Preference->{Type},
                 );
 
-              # set the complete value structure in GetParam to store it later in the search profile
+                # set the complete value structure in GetParam to store it later in the search profile
                 if ( IsHashRefWithData($DynamicFieldValue) ) {
                     %GetParam = ( %GetParam, %{$DynamicFieldValue} );
                 }
@@ -402,8 +402,7 @@ sub Run {
                     && $GetParam{ $TimeType . 'TimeStartYear' }
                     )
                 {
-                    $GetParam{ $TimeType . 'TimeNewerDate' }
-                        = $GetParam{ $TimeType . 'TimeStartYear' } . '-'
+                    $GetParam{ $TimeType . 'TimeNewerDate' } = $GetParam{ $TimeType . 'TimeStartYear' } . '-'
                         . $GetParam{ $TimeType . 'TimeStartMonth' } . '-'
                         . $GetParam{ $TimeType . 'TimeStartDay' }
                         . ' 00:00:00';
@@ -414,8 +413,7 @@ sub Run {
                     && $GetParam{ $TimeType . 'TimeStopYear' }
                     )
                 {
-                    $GetParam{ $TimeType . 'TimeOlderDate' }
-                        = $GetParam{ $TimeType . 'TimeStopYear' } . '-'
+                    $GetParam{ $TimeType . 'TimeOlderDate' } = $GetParam{ $TimeType . 'TimeStopYear' } . '-'
                         . $GetParam{ $TimeType . 'TimeStopMonth' } . '-'
                         . $GetParam{ $TimeType . 'TimeStopDay' }
                         . ' 23:59:59';
@@ -611,11 +609,30 @@ sub Run {
                     DynamicFields => 1,
                 );
 
+                if ( !%Data ) {
+
+                    # get ticket data instead
+                    %Data = $Self->{TicketObjectSearch}->TicketGet(
+                        TicketID      => $TicketID,
+                        DynamicFields => 1,
+                    );
+
+                    # set missing information
+                    $Data{Subject} = $Data{Title} || 'Untitled';
+                    $Data{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
+                        'This item has no articles yet.'
+                    );
+                    $Data{From} = '--';
+                }
+
                 for my $Key (qw(State Lock)) {
                     $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{$Key} );
                 }
 
-                $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
+                $Data{Age} = $Self->{LayoutObject}->CustomerAge(
+                    Age   => $Data{Age},
+                    Space => ' '
+                );
 
                 # get whole article (if configured!)
                 if ( $Self->{Config}->{SearchArticleCSVTree} ) {
@@ -623,13 +640,21 @@ sub Run {
                         TicketID      => $TicketID,
                         DynamicFields => 0,
                     );
-                    for my $Articles (@Article) {
-                        if ( $Articles->{Body} ) {
-                            $Data{ArticleTree}
-                                .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
-                                . $Articles->{Created}
-                                . "||<--------------\n"
-                                . $Articles->{Body};
+
+                    if ( $#Article == -1 ) {
+                        $Data{ArticleTree}
+                            .= 'This item has no articles yet.';
+                    }
+                    else
+                    {
+                        for my $Articles (@Article) {
+                            if ( $Articles->{Body} ) {
+                                $Data{ArticleTree}
+                                    .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
+                                    . $Articles->{Created}
+                                    . "||<--------------\n"
+                                    . $Articles->{Body};
+                            }
                         }
                     }
                 }
@@ -651,8 +676,7 @@ sub Run {
                     %Data,
                     %UserInfo,
                     AccountedTime =>
-                        $Self->{TicketObjectSearch}
-                        ->TicketAccountedTimeGet( TicketID => $TicketID ),
+                        $Self->{TicketObjectSearch}->TicketAccountedTimeGet( TicketID => $TicketID ),
                 );
 
                 my @Data;
@@ -704,11 +728,10 @@ sub Run {
 
             my %HeaderMap = (
                 TicketNumber => 'Ticket Number',
-                CustomerName => 'customer realname',
+                CustomerName => 'Customer Realname',
             );
 
-            my @CSVHeadTranslated
-                = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
+            my @CSVHeadTranslated = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
                 @CSVHead;
 
             my $CSV = $Self->{CSVObject}->Array2CSV(
@@ -755,8 +778,8 @@ sub Run {
                     );
 
                     # set missing information
-                    $Data{Subject} = $Data{Title};
-                    $Data{From}    = '--';
+                    $Data{Subject} = $Data{Title} || 'Untitled';
+                    $Data{From} = '--';
                 }
 
                 # customer info
@@ -785,7 +808,10 @@ sub Run {
                 );
 
                 # get age
-                $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
+                $Data{Age} = $Self->{LayoutObject}->CustomerAge(
+                    Age   => $Data{Age},
+                    Space => ' '
+                );
 
                 # customer info string
                 $UserInfo{CustomerName} = '(' . $UserInfo{CustomerName} . ')'
@@ -837,8 +863,7 @@ sub Run {
                 my $Time      = $Self->{LayoutObject}->Output( Template => '$Env{"Time"}' );
                 my $Url       = '';
                 if ( $ENV{REQUEST_URI} ) {
-                    $Url
-                        = $Self->{ConfigObject}->Get('HttpType') . '://'
+                    $Url = $Self->{ConfigObject}->Get('HttpType') . '://'
                         . $Self->{ConfigObject}->Get('FQDN')
                         . $ENV{REQUEST_URI};
                 }
@@ -857,27 +882,20 @@ sub Run {
                     # create the header
                     $CellData->[0]->[0]->{Content} = $Self->{ConfigObject}->Get('Ticket::Hook');
                     $CellData->[0]->[0]->{Font}    = 'ProportionalBold';
-                    $CellData->[0]->[1]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
-                    $CellData->[0]->[1]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[2]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('From');
-                    $CellData->[0]->[2]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[3]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Subject');
-                    $CellData->[0]->[3]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[4]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('State');
-                    $CellData->[0]->[4]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[5]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Queue');
-                    $CellData->[0]->[5]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[6]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('Owner');
-                    $CellData->[0]->[6]->{Font} = 'ProportionalBold';
-                    $CellData->[0]->[7]->{Content}
-                        = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID');
-                    $CellData->[0]->[7]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[1]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
+                    $CellData->[0]->[1]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[2]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('From');
+                    $CellData->[0]->[2]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[3]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Subject');
+                    $CellData->[0]->[3]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[4]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('State');
+                    $CellData->[0]->[4]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[5]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Queue');
+                    $CellData->[0]->[5]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[6]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('Owner');
+                    $CellData->[0]->[6]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[7]->{Content} = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID');
+                    $CellData->[0]->[7]->{Font}    = 'ProportionalBold';
 
                     # create the content array
                     my $CounterRow = 1;
@@ -932,7 +950,10 @@ sub Run {
                 );
 
                 # start table output
-                $Self->{PDFObject}->PageNew( %PageParam, FooterRight => $Page . ' 1', );
+                $Self->{PDFObject}->PageNew(
+                    %PageParam,
+                    FooterRight => $Page . ' 1',
+                );
                 PAGE:
                 for my $PageNumber ( 2 .. $MaxPages ) {
 
@@ -953,10 +974,9 @@ sub Run {
 
                 # return the pdf document
                 my $Filename = 'ticket_search';
-                my ( $s, $m, $h, $D, $M, $Y )
-                    = $Self->{TimeObject}->SystemTime2Date(
+                my ( $s, $m, $h, $D, $M, $Y ) = $Self->{TimeObject}->SystemTime2Date(
                     SystemTime => $Self->{TimeObject}->SystemTime(),
-                    );
+                );
                 $M = sprintf( "%02d", $M );
                 $D = sprintf( "%02d", $D );
                 $h = sprintf( "%02d", $h );
@@ -998,9 +1018,12 @@ sub Run {
             }
 
             # store last overview screen
-            my $URL
-                = "Action=AgentTicketSearch;Subaction=Search;Profile=$Self->{Profile};SortBy=$Self->{SortBy}"
-                . ";OrderBy=$Self->{OrderBy};TakeLastSearch=1;StartHit=$Self->{StartHit}";
+            my $URL = "Action=AgentTicketSearch;Subaction=Search"
+                . ";Profile=" . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ";SortBy=" . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
+                . ";OrderBy=" . $Self->{LayoutObject}->LinkEncode( $Self->{OrderBy} )
+                . ";TakeLastSearch=1;StartHit="
+                . $Self->{LayoutObject}->LinkEncode( $Self->{StartHit} );
 
             $Self->{SessionObject}->UpdateSessionID(
                 SessionID => $Self->{SessionID},
@@ -1023,12 +1046,16 @@ sub Run {
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
                 . ';SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
                 . ';OrderBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{OrderBy} )
-                . ';Profile=' . $Self->{Profile} . ';TakeLastSearch=1;Subaction=Search'
+                . ';Profile='
+                . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ';TakeLastSearch=1;Subaction=Search'
                 . ';';
             my $LinkSort = 'Filter='
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Filter} )
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
-                . ';Profile=' . $Self->{Profile} . ';TakeLastSearch=1;Subaction=Search'
+                . ';Profile='
+                . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ';TakeLastSearch=1;Subaction=Search'
                 . ';';
             my $LinkFilter = 'TakeLastSearch=1;Subaction=Search;Profile='
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
@@ -1037,11 +1064,12 @@ sub Run {
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
                 . ';TakeLastSearch=1&';
 
-            my $FilterLink
-                = 'SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
+            my $FilterLink = 'SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} )
                 . ';OrderBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{OrderBy} )
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
-                . ';Profile=' . $Self->{Profile} . ';TakeLastSearch=1;Subaction=Search'
+                . ';Profile='
+                . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} )
+                . ';TakeLastSearch=1;Subaction=Search'
                 . ';';
             $Output .= $Self->{LayoutObject}->TicketListShow(
                 TicketIDs => \@ViewableTicketIDs,
@@ -1168,6 +1196,23 @@ sub Run {
                 Key   => 'Body',
                 Value => 'Body',
             },
+        );
+
+        # show Article Name option only if the ArticleStorage is in the DB
+        if (
+            $Self->{ConfigObject}->Get('Ticket::StorageModule') eq
+            'Kernel::System::Ticket::ArticleStorageDB'
+            )
+        {
+            push @Attributes, (
+                {
+                    Key   => 'AttachmentName',
+                    Value => 'Attachment Name',
+                },
+            );
+        }
+
+        push @Attributes, (
             {
                 Key      => '',
                 Value    => '-',
@@ -1185,22 +1230,51 @@ sub Run {
                 Key   => 'StateIDs',
                 Value => 'State',
             },
-            {
-                Key   => 'QueueIDs',
-                Value => 'Queue',
-            },
             {
                 Key   => 'PriorityIDs',
                 Value => 'Priority',
             },
             {
-                Key   => 'OwnerIDs',
-                Value => 'Owner',
+                Key   => 'LockIDs',
+                Value => 'Lock',
+            },
+            {
+                Key   => 'QueueIDs',
+                Value => 'Queue',
             },
             {
                 Key   => 'CreatedQueueIDs',
                 Value => 'Created in Queue',
             },
+        );
+
+        if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
+            push @Attributes, (
+                {
+                    Key   => 'TypeIDs',
+                    Value => 'Type',
+                },
+            );
+        }
+
+        if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
+            push @Attributes, (
+                {
+                    Key   => 'ServiceIDs',
+                    Value => 'Service',
+                },
+                {
+                    Key   => 'SLAIDs',
+                    Value => 'SLA',
+                },
+            );
+        }
+
+        push @Attributes, (
+            {
+                Key   => 'OwnerIDs',
+                Value => 'Owner',
+            },
             {
                 Key   => 'CreatedUserIDs',
                 Value => 'Created by',
@@ -1222,23 +1296,60 @@ sub Run {
                 },
             );
         }
-        if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
+
+        push @Attributes, (
+            {
+                Key      => '',
+                Value    => '-',
+                Disabled => 1,
+            },
+            {
+                Key   => 'TicketChangeTimePoint',
+                Value => 'Ticket Change Time (before/after)',
+            },
+            {
+                Key   => 'TicketChangeTimeSlot',
+                Value => 'Ticket Change Time (between)',
+            },
+            {
+                Key   => 'TicketCloseTimePoint',
+                Value => 'Ticket Close Time (before/after)',
+            },
+            {
+                Key   => 'TicketCloseTimeSlot',
+                Value => 'Ticket Close Time (between)',
+            },
+            {
+                Key   => 'TicketCreateTimePoint',
+                Value => 'Ticket Create Time (before/after)',
+            },
+            {
+                Key   => 'TicketCreateTimeSlot',
+                Value => 'Ticket Create Time (between)',
+            },
+            {
+                Key   => 'TicketEscalationTimePoint',
+                Value => 'Ticket Escalation Time (before/after)',
+            },
+            {
+                Key   => 'TicketEscalationTimeSlot',
+                Value => 'Ticket Escalation Time (between)',
+            },
+            {
+                Key   => 'ArticleCreateTimePoint',
+                Value => 'Article Create Time (before/after)',
+            },
+            {
+                Key   => 'ArticleCreateTimeSlot',
+                Value => 'Article Create Time (between)',
+            },
+        );
+
+        if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
             push @Attributes, (
                 {
-                    Key   => 'TypeIDs',
-                    Value => 'Type',
-                },
-            );
-        }
-        if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
-            push @Attributes, (
-                {
-                    Key   => 'ServiceIDs',
-                    Value => 'Service',
-                },
-                {
-                    Key   => 'SLAIDs',
-                    Value => 'SLA',
+                    Key   => 'SearchInArchive',
+                    Value => 'Archive Search',
                 },
             );
         }
@@ -1262,7 +1373,6 @@ sub Run {
                         Disabled => 1,
                     },
                 );
-
                 $DynamicFieldSeparator = 0;
             }
 
@@ -1301,17 +1411,6 @@ sub Run {
             }
         }
 
-        # create a separator if a dynamic field attribute was pushed
-        if ( !$DynamicFieldSeparator ) {
-            push @Attributes, (
-                {
-                    Key      => '',
-                    Value    => '-',
-                    Disabled => 1,
-                },
-            );
-        }
-
         # create HTML strings for all dynamic fields
         my %DynamicFieldHTML;
 
@@ -1399,60 +1498,6 @@ sub Run {
             }
         }
 
-        push @Attributes, (
-            {
-                Key   => 'LockIDs',
-                Value => 'Lock',
-            },
-            {
-                Key   => 'TicketCreateTimePoint',
-                Value => 'Ticket Create Time (before/after)',
-            },
-            {
-                Key   => 'TicketCreateTimeSlot',
-                Value => 'Ticket Create Time (between)',
-            },
-            {
-                Key   => 'TicketChangeTimePoint',
-                Value => 'Ticket Change Time (before/after)',
-            },
-            {
-                Key   => 'TicketChangeTimeSlot',
-                Value => 'Ticket Change Time (between)',
-            },
-            {
-                Key   => 'TicketCloseTimePoint',
-                Value => 'Ticket Close Time (before/after)',
-            },
-            {
-                Key   => 'TicketCloseTimeSlot',
-                Value => 'Ticket Close Time (between)',
-            },
-            {
-                Key   => 'TicketEscalationTimePoint',
-                Value => 'Ticket Escalation Time (before/after)',
-            },
-            {
-                Key   => 'TicketEscalationTimeSlot',
-                Value => 'Ticket Escalation Time (between)',
-            },
-            {
-                Key   => 'ArticleCreateTimePoint',
-                Value => 'Article Create Time (before/after)',
-            },
-            {
-                Key   => 'ArticleCreateTimeSlot',
-                Value => 'Article Create Time (between)',
-            },
-        );
-        if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
-            push @Attributes, (
-                {
-                    Key   => 'SearchInArchive',
-                    Value => 'Archive Search',
-                },
-            );
-        }
         $Param{AttributesStrg} = $Self->{LayoutObject}->BuildSelection(
             Data     => \@Attributes,
             Name     => 'Attribute',
@@ -1516,7 +1561,9 @@ sub Run {
         # build service string
         if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
 
-            my %Service = $Self->{ServiceObject}->ServiceList( UserID => $Self->{UserID}, );
+            my %Service = $Self->{ServiceObject}->ServiceList(
+                UserID => $Self->{UserID},
+            );
             $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Service,
                 Name        => 'ServiceIDs',
@@ -1528,7 +1575,9 @@ sub Run {
                 Translation => 0,
                 Max         => 200,
             );
-            my %SLA = $Self->{SLAObject}->SLAList( UserID => $Self->{UserID}, );
+            my %SLA = $Self->{SLAObject}->SLAList(
+                UserID => $Self->{UserID},
+            );
             $Param{SLAsStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%SLA,
                 Name        => 'SLAIDs',
@@ -1547,7 +1596,7 @@ sub Run {
                 Print  => 'Print',
                 CSV    => 'CSV',
             },
-            Name => 'ResultForm',
+            Name       => 'ResultForm',
             SelectedID => $GetParam{ResultForm} || 'Normal',
         );
 
@@ -1559,7 +1608,7 @@ sub Run {
                     NotArchivedTickets => 'Unarchived tickets',
                     AllTickets         => 'All tickets',
                 },
-                Name => 'SearchInArchive',
+                Name       => 'SearchInArchive',
                 SelectedID => $GetParam{SearchInArchive} || 'NotArchivedTickets',
             );
         }
@@ -1652,7 +1701,7 @@ sub Run {
                 'Last'   => 'within the last ...',
                 'Before' => 'more than ... ago',
             },
-            Name => 'ArticleCreateTimePointStart',
+            Name       => 'ArticleCreateTimePointStart',
             SelectedID => $GetParam{ArticleCreateTimePointStart} || 'Last',
         );
         $Param{ArticleCreateTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1688,7 +1737,7 @@ sub Run {
                 'Last'   => 'within the last ...',
                 'Before' => 'more than ... ago',
             },
-            Name => 'TicketCreateTimePointStart',
+            Name       => 'TicketCreateTimePointStart',
             SelectedID => $GetParam{TicketCreateTimePointStart} || 'Last',
         );
         $Param{TicketCreateTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1725,7 +1774,7 @@ sub Run {
                 'Last'   => 'within the last ...',
                 'Before' => 'more than ... ago',
             },
-            Name => 'TicketChangeTimePointStart',
+            Name       => 'TicketChangeTimePointStart',
             SelectedID => $GetParam{TicketChangeTimePointStart} || 'Last',
         );
         $Param{TicketChangeTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1762,7 +1811,7 @@ sub Run {
                 'Last'   => 'within the last ...',
                 'Before' => 'more than ... ago',
             },
-            Name => 'TicketCloseTimePointStart',
+            Name       => 'TicketCloseTimePointStart',
             SelectedID => $GetParam{TicketCloseTimePointStart} || 'Last',
         );
         $Param{TicketCloseTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1800,7 +1849,7 @@ sub Run {
                 'Next'   => 'within the next ...',
                 'Before' => 'more than ... ago',
             },
-            Name => 'TicketEscalationTimePointStart',
+            Name       => 'TicketEscalationTimePointStart',
             SelectedID => $GetParam{TicketEscalationTimePointStart} || 'Last',
         );
         $Param{TicketEscalationTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
@@ -1837,7 +1886,9 @@ sub Run {
 
         # build type string
         if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
-            my %Type = $Self->{TypeObject}->TypeList( UserID => $Self->{UserID}, );
+            my %Type = $Self->{TypeObject}->TypeList(
+                UserID => $Self->{UserID},
+            );
             $Param{TypesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Type,
                 Name        => 'TypeIDs',
@@ -1918,39 +1969,50 @@ sub Run {
             @ShownAttributes = split /;/, $GetParamBackup{ShownAttributes};
         }
         my %AlreadyShown;
-        for my $Item (@Attributes) {
-            my $Key = $Item->{Key};
-            next if !$Key;
 
-            # check if shown
-            if (@ShownAttributes) {
-                my $Show = 0;
-                for my $ShownAttribute (@ShownAttributes) {
-                    if ( 'Label' . $Key eq $ShownAttribute ) {
-                        $Show = 1;
-                        last;
+        if ($Profile) {
+            for my $Item (@Attributes) {
+                my $Key = $Item->{Key};
+                next if !$Key;
+
+                # check if shown
+                if (@ShownAttributes) {
+                    my $Show = 0;
+                    for my $ShownAttribute (@ShownAttributes) {
+                        if ( 'Label' . $Key eq $ShownAttribute ) {
+                            $Show = 1;
+                            last;
+                        }
+                    }
+                    next if !$Show;
+                }
+                else {
+                    # Skip undefined
+                    next if !defined $GetParamBackup{$Key};
+
+                    # Skip empty strings
+                    next if $GetParamBackup{$Key} eq '';
+
+                    # Skip empty arrays
+                    if ( ref $GetParamBackup{$Key} eq 'ARRAY' && !@{ $GetParamBackup{$Key} } ) {
+                        next;
                     }
                 }
-                next if !$Show;
-            }
-            else {
-                next if !defined $GetParamBackup{$Key};
-                next if $GetParamBackup{$Key} eq '';
-            }
 
-            # show attribute
-            next if $AlreadyShown{$Key};
-            $AlreadyShown{$Key} = 1;
-            $Self->{LayoutObject}->Block(
-                Name => 'SearchAJAXShow',
-                Data => {
-                    Attribute => $Key,
-                },
-            );
+                # show attribute
+                next if $AlreadyShown{$Key};
+                $AlreadyShown{$Key} = 1;
+                $Self->{LayoutObject}->Block(
+                    Name => 'SearchAJAXShow',
+                    Data => {
+                        Attribute => $Key,
+                    },
+                );
+            }
         }
 
-        # if no attribute is shown, show fulltext search
-        if ( !$Profile ) {
+        # No profile, show default screen
+        else {
 
             # Merge regular show/hide settings and the settings for the dynamic fields
             my %Defaults = %{ $Self->{Config}->{Defaults} || {} };
@@ -1960,10 +2022,23 @@ sub Run {
                 }
             }
 
+            my @OrderedDefaults;
             if (%Defaults) {
-                for my $Key ( sort keys %Defaults ) {
-                    next if $Key eq 'DynamicField';    # Ignore entry for DF config
-                    next if $AlreadyShown{$Key};
+
+                # ordering atributes on the same order like in Atributes
+                for my $Item (@Attributes) {
+                    my $KeyAtr = $Item->{Key};
+                    for my $Key ( sort keys %Defaults ) {
+                        if ( $Key eq $KeyAtr ) {
+                            push @OrderedDefaults, $Key;
+                        }
+                    }
+                }
+
+                KEY:
+                for my $Key (@OrderedDefaults) {
+                    next KEY if $Key eq 'DynamicField';    # Ignore entry for DF config
+                    next KEY if $AlreadyShown{$Key};
                     $AlreadyShown{$Key} = 1;
 
                     $Self->{LayoutObject}->Block(
@@ -1974,7 +2049,9 @@ sub Run {
                     );
                 }
             }
-            else {
+
+            # If no attribute is shown, show fulltext search.
+            if ( !keys %AlreadyShown ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'SearchAJAXShow',
                     Data => {
