@@ -1,8 +1,6 @@
 # --
 # Kernel/Output/HTML/ServicePreferencesGeneric.pm
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
-# --
-# $Id: ServicePreferencesGeneric.pm,v 1.2 2009-07-07 15:45:19 mh Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +12,6 @@ package Kernel::Output::HTML::ServicePreferencesGeneric;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.2 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -25,7 +20,7 @@ sub new {
     bless( $Self, $Type );
 
     # get env
-    for ( keys %Param ) {
+    for ( sort keys %Param ) {
         $Self->{$_} = $Param{$_};
     }
 
@@ -46,8 +41,7 @@ sub Param {
     my @Params = ();
     my $GetParam = $Self->{ParamObject}->GetParam( Param => $Self->{ConfigItem}->{PrefKey} );
     if ( !defined($GetParam) ) {
-        $GetParam
-            = defined( $Param{ServiceData}->{ $Self->{ConfigItem}->{PrefKey} } )
+        $GetParam = defined( $Param{ServiceData}->{ $Self->{ConfigItem}->{PrefKey} } )
             ? $Param{ServiceData}->{ $Self->{ConfigItem}->{PrefKey} }
             : $Self->{ConfigItem}->{DataSelected};
     }
@@ -65,7 +59,7 @@ sub Param {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    for my $Key ( keys %{ $Param{GetParam} } ) {
+    for my $Key ( sort keys %{ $Param{GetParam} } ) {
         my @Array = @{ $Param{GetParam}->{$Key} };
         for (@Array) {
 
