@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/ToolBarLink.pm
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -52,11 +52,14 @@ sub Run {
     my $Priority  = $Param{Config}->{Priority};
     my $AccessKey = $Param{Config}->{AccessKey};
     my $CssClass  = $Param{Config}->{CssClass};
+    my $Icon      = $Param{Config}->{Icon};
+
     my %Return;
     $Return{$Priority} = {
         Block       => 'ToolBarItem',
         Description => $Text,
         Class       => $CssClass,
+        Icon        => $Icon,
         Link        => $URL,
         AccessKey   => $AccessKey,
     };
