@@ -1,6 +1,6 @@
 # --
 # Kernel/System/AuthSession/FS.pm - provides session filesystem backend
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,9 +11,7 @@ package Kernel::System::AuthSession::FS;
 
 use strict;
 use warnings;
-umask 002;
 
-use Digest::MD5;
 use Storable;
 
 sub new {
@@ -253,16 +251,14 @@ sub CreateSessionID {
     my $RemoteUserAgent = $ENV{HTTP_USER_AGENT} || 'none';
 
     # create session id
-    my $MD5 = Digest::MD5->new();
-    $MD5->add(
-        ( $TimeNow . int( rand 999999999 ) . $Self->{SystemID} ) . $RemoteAddr . $RemoteUserAgent
+    my $SessionID = $Self->{SystemID} . $Self->{MainObject}->GenerateRandomString(
+        Length => 32,
     );
-    my $SessionID = $Self->{SystemID} . $MD5->hexdigest();
 
     # create challenge token
-    $MD5 = Digest::MD5->new();
-    $MD5->add( $TimeNow . $SessionID );
-    my $ChallengeToken = $MD5->hexdigest();
+    my $ChallengeToken = $Self->{MainObject}->GenerateRandomString(
+        Length => 32,
+    );
 
     my %Data;
     KEY:
@@ -288,7 +284,7 @@ sub CreateSessionID {
         Content         => \$DataContent,
         Type            => 'Local',
         Mode            => 'binmode',
-        Permission      => '664',
+        Permission      => '660',
         DisableWarnings => 1,
     );
 
@@ -311,7 +307,7 @@ sub CreateSessionID {
         Content         => \$StateContent,
         Type            => 'Local',
         Mode            => 'binmode',
-        Permission      => '664',
+        Permission      => '660',
         DisableWarnings => 1,
     );
 
@@ -515,7 +511,7 @@ sub DESTROY {
             Content         => \$DataContent,
             Type            => 'Local',
             Mode            => 'binmode',
-            Permission      => '664',
+            Permission      => '660',
             DisableWarnings => 1,
         );
 
@@ -533,7 +529,7 @@ sub DESTROY {
             Content         => \$StateContent,
             Type            => 'Local',
             Mode            => 'binmode',
-            Permission      => '664',
+            Permission      => '660',
             DisableWarnings => 1,
         );
     }
