@@ -1,8 +1,6 @@
 # --
 # Kernel/System/CustomerUser.pm - some customer user functions
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: CustomerUser.pm,v 1.63.2.1 2012-06-28 21:55:42 mb Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,9 +13,9 @@ use strict;
 use warnings;
 
 use Kernel::System::CustomerCompany;
+use Kernel::System::EventHandler;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.63.2.1 $) [1];
+use base qw(Kernel::System::EventHandler);
 
 =head1 NAME
 
@@ -89,7 +87,7 @@ sub new {
     my $GeneratorModule = $Self->{ConfigObject}->Get('CustomerPreferences')->{Module}
         || 'Kernel::System::CustomerUser::Preferences::DB';
     if ( $Self->{MainObject}->Require($GeneratorModule) ) {
-        $Self->{PreferencesObject} = $GeneratorModule->new(%Param);
+        $Self->{PreferencesObject} = $GeneratorModule->new( %{$Self} );
     }
 
     # load customer user backend module
@@ -104,13 +102,22 @@ sub new {
         }
         $Self->{"CustomerUser$Count"} = $GenericModule->new(
             Count => $Count,
-            %Param,
+            %{$Self},
             PreferencesObject => $Self->{PreferencesObject},
             CustomerUserMap   => $Self->{ConfigObject}->Get("CustomerUser$Count"),
         );
     }
 
-    $Self->{CustomerCompanyObject} = Kernel::System::CustomerCompany->new(%Param);
+    $Self->{CustomerCompanyObject} = Kernel::System::CustomerCompany->new( %{$Self} );
+
+    # init of event handler
+    $Self->EventHandlerInit(
+        Config     => 'CustomerUser::EventModulePost',
+        BaseObject => 'CustomerUserObject',
+        Objects    => {
+            %{$Self},
+        },
+    );
 
     return $Self;
 }
@@ -153,21 +160,30 @@ sub CustomerSourceList {
 
 to search users
 
+    # text search
     my %List = $CustomerUserObject->CustomerSearch(
         Search => '*some*', # also 'hans+huber' possible
         Valid  => 1, # not required, default 1
     );
 
+    # username search
     my %List = $CustomerUserObject->CustomerSearch(
         UserLogin => '*some*',
         Valid     => 1, # not required, default 1
     );
 
+    # email search
     my %List = $CustomerUserObject->CustomerSearch(
         PostMasterSearch => 'email@example.com',
         Valid            => 1, # not required, default 1
     );
 
+    # search by CustomerID
+    my %List = $CustomerUserObject->CustomerSearch(
+        CustomerID       => 'CustomerID123',
+        Valid            => 1, # not required, default 1
+    );
+
 =cut
 
 sub CustomerSearch {
@@ -218,6 +234,39 @@ sub CustomerUserList {
     return %Data;
 }
 
+=item CustomerIDList()
+
+return a list of with all known unique CustomerIDs of the registered customers users (no SearchTerm),
+or a filtered list where the CustomerIDs must contain a search term.
+
+    my @CustomerIDs = $CustomerUserObject->CustomerIDList(
+        SearchTerm  => 'somecustomer',    # optional
+        Valid       => 1,                 # optional
+    );
+
+=cut
+
+sub CustomerIDList {
+    my ( $Self, %Param ) = @_;
+
+    my @Data;
+    for my $Count ( '', 1 .. 10 ) {
+
+        # next if customer backend is not used
+        next if !$Self->{"CustomerUser$Count"};
+
+        # get customer list result of backend and merge it
+        push @Data, $Self->{"CustomerUser$Count"}->CustomerIDList(%Param);
+    }
+
+    # make entries unique
+    my %Tmp;
+    @Tmp{@Data} = undef;
+    @Data = sort { lc $a cmp lc $b } keys %Tmp;
+
+    return @Data;
+}
+
 =item CustomerName()
 
 get customer user name
@@ -299,7 +348,7 @@ sub CustomerUserDataGet {
         # add preferences defaults
         my $Config = $Self->{ConfigObject}->Get('CustomerPreferencesGroups');
         if ($Config) {
-            for my $Key ( keys %{$Config} ) {
+            for my $Key ( sort keys %{$Config} ) {
 
                 # next if no default data exists
                 next if !defined $Config->{$Key}->{DataSelected};
@@ -322,6 +371,8 @@ sub CustomerUserDataGet {
             %Company = $Self->{CustomerCompanyObject}->CustomerCompanyGet(
                 CustomerID => $Customer{UserCustomerID},
             );
+
+            $Company{CustomerCompanyValidID} = $Company{ValidID};
         }
 
         # return customer data
@@ -330,7 +381,7 @@ sub CustomerUserDataGet {
             %Customer,
             Source        => "CustomerUser$Count",
             Config        => $Self->{ConfigObject}->Get("CustomerUser$Count"),
-            CompanyConfig => $Self->{ConfigObject}->Get("CustomerCompany"),
+            CompanyConfig => $Self->{ConfigObject}->Get( $Company{Source} // 'CustomerCompany' ),
         );
     }
     return;
@@ -373,7 +424,22 @@ sub CustomerUserAdd {
             return;
         }
     }
-    return $Self->{ $Param{Source} }->CustomerUserAdd(%Param);
+
+    my $Result = $Self->{ $Param{Source} }->CustomerUserAdd(%Param);
+    return if !$Result;
+
+    # trigger event
+    $Self->EventHandler(
+        Event => 'CustomerUserAdd',
+        Data  => {
+            UserLogin => $Param{UserLogin},
+            NewData   => \%Param,
+        },
+        UserID => $Param{UserID},
+    );
+
+    return $Result;
+
 }
 
 =item CustomerUserUpdate()
@@ -399,7 +465,10 @@ sub CustomerUserUpdate {
 
     # check needed stuff
     if ( !$Param{UserLogin} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "User UserLogin!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need UserLogin!"
+        );
         return;
     }
 
@@ -424,7 +493,22 @@ sub CustomerUserUpdate {
         );
         return;
     }
-    return $Self->{ $User{Source} }->CustomerUserUpdate(%Param);
+    my $Result = $Self->{ $User{Source} }->CustomerUserUpdate(%Param);
+    return if !$Result;
+
+    # trigger event
+    $Self->EventHandler(
+        Event => 'CustomerUserUpdate',
+        Data  => {
+            UserLogin => $Param{ID} || $Param{UserLogin},
+            NewData   => \%Param,
+            OldData   => \%User,
+        },
+        UserID => $Param{UserID},
+    );
+
+    return $Result;
+
 }
 
 =item SetPassword()
@@ -443,7 +527,10 @@ sub SetPassword {
 
     # check needed stuff
     if ( !$Param{UserLogin} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'User UserLogin!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'User UserLogin!'
+        );
         return;
     }
 
@@ -496,7 +583,10 @@ sub SetPreferences {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'User UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need UserID!'
+        );
         return;
     }
 
@@ -534,7 +624,10 @@ sub GetPreferences {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'User UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need UserID!'
+        );
         return;
     }
 
@@ -563,7 +656,7 @@ search in user preferences
 
     my %UserList = $CustomerUserObject->SearchPreferences(
         Key   => 'UserSomeKey',
-        Value => 'SomeValue',
+        Value => 'SomeValue',   # optional, limit to a certain value/pattern
     );
 
 =cut
@@ -590,6 +683,7 @@ sub SearchPreferences {
         }
         %Data = ( %SubData, %Data );
     }
+
     return %Data;
 }
 
@@ -608,21 +702,16 @@ sub TokenGenerate {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need UserID!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need UserID!"
+        );
         return;
     }
 
-    # The list of characters that can appear in a randomly generated token.
-    my @Chars = ( 0 .. 9, 'A' .. 'Z', 'a' .. 'z' );
-
-    # The number of characters in the list.
-    my $CharsLen = scalar @Chars;
-
-    # Generate the token.
-    my $Token = 'C';
-    for ( my $i = 0; $i < 14; $i++ ) {
-        $Token .= $Chars[ rand($CharsLen) ];
-    }
+    my $Token = $Self->{MainObject}->GenerateRandomString(
+        Length => 14,
+    );
 
     # save token in preferences
     $Self->SetPreferences(
@@ -631,7 +720,6 @@ sub TokenGenerate {
         UserID => $Param{UserID},
     );
 
-    # Return the Token.
     return $Token;
 }
 
@@ -651,7 +739,10 @@ sub TokenCheck {
 
     # check needed stuff
     if ( !$Param{Token} || !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need Token and UserID!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need Token and UserID!"
+        );
         return;
     }
 
@@ -661,21 +752,26 @@ sub TokenCheck {
     );
 
     # check requested vs. stored token
-    if ( $Preferences{UserToken} && $Preferences{UserToken} eq $Param{Token} ) {
+    return if !$Preferences{UserToken};
+    return if $Preferences{UserToken} ne $Param{Token};
 
-        # reset password token
-        $Self->SetPreferences(
-            Key    => 'UserToken',
-            Value  => '',
-            UserID => $Param{UserID},
-        );
+    # reset password token
+    $Self->SetPreferences(
+        Key    => 'UserToken',
+        Value  => '',
+        UserID => $Param{UserID},
+    );
 
-        # return true if token is valid
-        return 1;
-    }
+    return 1;
+}
 
-    # return false if token is invalid
-    return;
+sub DESTROY {
+    my $Self = shift;
+
+    # execute all transaction events
+    $Self->EventHandlerTransaction();
+
+    return 1;
 }
 
 1;
@@ -691,9 +787,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.63.2.1 $ $Date: 2012-06-28 21:55:42 $
-
-=cut
