@@ -1,6 +1,6 @@
 # --
 # Kernel/System/DynamicField.pm - DynamicFields configuration backend
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -96,7 +96,7 @@ sub new {
 
     # set lower if database is case sensitive
     $Self->{Lower} = '';
-    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+    if ( $Self->{DBObject}->GetDatabaseFunction('CaseSensitive') ) {
         $Self->{Lower} = 'LOWER';
     }
 
@@ -195,11 +195,11 @@ sub DynamicFieldAdd {
         SQL =>
             'INSERT INTO dynamic_field (internal_field, name, label, field_Order, field_type, object_type,'
             .
-            'config, valid_id, create_time, create_by, change_time, change_by)' .
+            ' config, valid_id, create_time, create_by, change_time, change_by)' .
             ' VALUES (?, ?, ?, ?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
             \$InternalField, \$Param{Name}, \$Param{Label}, \$Param{FieldOrder}, \$Param{FieldType},
-            \$Param{ObjectType}, \$Config, \$Param{ValidID}, \$Param{UserID}, \$Param{UserID},
+            \$Param{ObjectType}, \$Config, \$Param{ValidID}, \$Param{UserID}, \$Param{UserID}
         ],
     );
 
@@ -207,6 +207,9 @@ sub DynamicFieldAdd {
     $Self->{CacheObject}->CleanUp(
         Type => 'DynamicField',
     );
+    $Self->{CacheObject}->CleanUp(
+        Type => 'DynamicFieldValue',
+    );
 
     my $DynamicField = $Self->DynamicFieldGet(
         Name => $Param{Name},
@@ -447,6 +450,9 @@ sub DynamicFieldUpdate {
     $Self->{CacheObject}->CleanUp(
         Type => 'DynamicField',
     );
+    $Self->{CacheObject}->CleanUp(
+        Type => 'DynamicFieldValue',
+    );
 
     # re-order field list if a change in the order was made
     if ( $Reorder && $ChangedOrder ) {
@@ -516,6 +522,9 @@ sub DynamicFieldDelete {
     $Self->{CacheObject}->CleanUp(
         Type => 'DynamicField',
     );
+    $Self->{CacheObject}->CleanUp(
+        Type => 'DynamicFieldValue',
+    );
 
     return 1;
 }
