@@ -1,6 +1,6 @@
 # --
 # Kernel/System/State.pm - All ticket state related functions
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,8 +17,6 @@ use Kernel::System::SysConfig;
 use Kernel::System::Time;
 use Kernel::System::Valid;
 
-use vars qw(@ISA);
-
 =head1 NAME
 
 Kernel::System::State - state lib
@@ -40,7 +38,6 @@ create an object
     use Kernel::Config;
     use Kernel::System::Encode;
     use Kernel::System::Log;
-    use Kernel::System::Time;
     use Kernel::System::Main;
     use Kernel::System::DB;
     use Kernel::System::State;
@@ -53,10 +50,6 @@ create an object
         ConfigObject => $ConfigObject,
         EncodeObject => $EncodeObject,
     );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
     my $MainObject = Kernel::System::Main->new(
         ConfigObject => $ConfigObject,
         EncodeObject => $EncodeObject,
@@ -90,8 +83,8 @@ sub new {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
-    # create addititional objects
-    $Self->{ValidObject}         = Kernel::System::Valid->new(%Param);
+    # create additional objects
+    $Self->{ValidObject}         = Kernel::System::Valid->new( %{$Self} );
     $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
         %Param,
         Type => 'State',
@@ -126,7 +119,10 @@ sub StateAdd {
     # check needed stuff
     for (qw(Name ValidID TypeID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -195,7 +191,10 @@ sub StateGet {
 
     # check needed stuff
     if ( !$Param{ID} && !$Param{Name} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need ID or Name!" );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Need ID or Name!"
+        );
         return;
     }
 
@@ -285,7 +284,10 @@ sub StateUpdate {
     # check needed stuff
     for (qw(ID Name ValidID TypeID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
@@ -354,12 +356,18 @@ sub StateGetStatesByType {
 
     # check needed stuff
     if ( !$Param{Result} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Result!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Result!'
+        );
         return;
     }
 
     if ( !$Param{Type} && !$Param{StateType} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Type or StateType!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Type or StateType!'
+        );
         return;
     }
 
@@ -498,7 +506,10 @@ sub StateList {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'UserID!'
+        );
         return;
     }
 
@@ -554,7 +565,10 @@ sub StateLookup {
 
     # check needed stuff
     if ( !$Param{State} && !$Param{StateID} ) {
-        $Self->{LogObject}->Log( State => 'error', Message => 'Need State or StateID!' );
+        $Self->{LogObject}->Log(
+            State   => 'error',
+            Message => 'Need State or StateID!'
+        );
         return;
     }
 
@@ -618,7 +632,10 @@ sub StateTypeList {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'UserID!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'UserID!'
+        );
         return;
     }
 
@@ -639,7 +656,10 @@ sub StateTypeList {
     }
 
     # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Data );
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \%Data
+    );
 
     return %Data;
 }
