@@ -1,8 +1,6 @@
 # --
 # Kernel/System/WebUserAgent.pm - a web user agent
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: WebUserAgent.pm,v 1.5 2010-10-18 19:27:13 mb Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,8 +14,7 @@ use warnings;
 
 use LWP::UserAgent;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.5 $) [1];
+use Kernel::System::VariableCheck qw(:all);
 
 =head1 NAME
 
@@ -95,17 +92,35 @@ sub new {
 
 =item Request()
 
-return the content of requested URL
+return the content of requested URL.
+
+Simple GET request:
 
     my %Response = $WebUserAgentObject->Request(
         URL => 'http://example.com/somedata.xml',
     );
 
+Or a POST request; attributes can be a hashref like this:
+
+    my %Response = $WebUserAgentObject->Request(
+        URL  => 'http://example.com/someurl',
+        Type => 'POST',
+        Data => { Attribute1 => 'Value', Attribute2 => 'Value2' },
+    );
+
+alternatively, you can use an arrayref like this:
+
+    my %Response = $WebUserAgentObject->Request(
+        URL  => 'http://example.com/someurl',
+        Type => 'POST',
+        Data => [ Attribute => 'Value', Attribute => 'OtherValue' ],
+    );
+
 returns
 
     %Response = (
-        Status  => 200,         # http status
-        Content => $ContentRef, # content of requested site
+        Status  => '200 OK',    # http status
+        Content => $ContentRef, # content of requested URL
     );
 
 =cut
@@ -113,14 +128,19 @@ returns
 sub Request {
     my ( $Self, %Param ) = @_;
 
+    # define method - default to GET
+    $Param{Type} ||= 'GET';
+
     my $Response;
 
     {
-        # set HTTPS proxy for ssl requests, localize %ENV because of mod_perl
-        local %ENV = %ENV;
+        # Set HTTPS proxy for ssl requests. We must not use "local %ENV" here!
+        # See http://bugs.otrs.org/show_bug.cgi?id=10577.
+        # It should also not be needed as we have PerlOptions +SetupEnv in our apache
+        #   configuration, and %ENV will be repopulated for every request.
 
         # if a proxy is set, extract it and use it as environment variables for HTTPS
-        if ( defined $Self->{Proxy} && $Self->{Proxy} =~ /:\/\/(.*)\// ) {
+        if ( $Self->{Proxy} =~ /:\/\/(.*)\// ) {
             my $ProxyAddress = $1;
 
             # extract authentication information if needed
@@ -140,6 +160,23 @@ sub Request {
         # init agent
         my $UserAgent = LWP::UserAgent->new();
 
+        # In some scenarios like transparent HTTPS proxies, it can be neccessary to turn off
+        #   SSL certificate validation.
+        if ( $Self->{ConfigObject}->Get('WebUserAgent::DisableSSLVerification') ) {
+            my $Loaded = $Self->{MainObject}->Require(
+                'Net::SSLeay',
+                Silent => 1,
+            );
+            if ($Loaded) {
+                $UserAgent->ssl_opts(
+                    verify_hostname => 0,
+                );
+                $UserAgent->ssl_opts(
+                    SSL_verify_mode => Net::SSLeay::VERIFY_NONE(),
+                );
+            }
+        }
+
         # set timeout
         $UserAgent->timeout( $Self->{Timeout} );
 
@@ -154,17 +191,36 @@ sub Request {
             $UserAgent->proxy( [ 'http', 'ftp' ], $Self->{Proxy} );
         }
 
-        # get file
-        $Response = $UserAgent->get( $Param{URL} );
-        if ( !$Response->is_success() ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Can't get file from $Param{URL}: " . $Response->status_line(),
-            );
-            return (
-                Status => $Response->status_line(),
-            );
+        if ( $Param{Type} eq 'GET' ) {
+
+            # perform get request on URL
+            $Response = $UserAgent->get( $Param{URL} );
         }
+
+        else {
+
+            # check for Data param
+            if ( !IsArrayRefWithData( $Param{Data} ) && !IsHashRefWithData( $Param{Data} ) ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message =>
+                        'WebUserAgent POST: Need Data param containing a hashref or arrayref with data.',
+                );
+                return ( Status => 0 );
+            }
+
+            # perform post request plus data
+            $Response = $UserAgent->post( $Param{URL}, $Param{Data} );
+        }
+    }
+    if ( !$Response->is_success() ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Can't perform $Param{Type} on $Param{URL}: " . $Response->status_line(),
+        );
+        return (
+            Status => $Response->status_line(),
+        );
     }
 
     # return request
@@ -187,9 +243,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.5 $ $Date: 2010-10-18 19:27:13 $
-
-=cut
