@@ -1,9 +1,7 @@
 #!/usr/bin/perl
 # --
 # bin/otrs.xml2sql.pl - a xml 2 sql processor
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: otrs.xml2sql.pl,v 1.13 2013/01/22 10:14:09 mg Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -30,9 +28,6 @@ use lib dirname($RealBin);
 use lib dirname($RealBin) . '/Kernel/cpan-lib';
 use lib dirname($RealBin) . '/Custom';
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.13 $) [1];
-
 use Getopt::Std;
 
 use Kernel::Config;
@@ -47,7 +42,7 @@ my %Opts = ();
 getopt( 'hton', \%Opts );
 if ( $Opts{'h'} || !%Opts ) {
     print <<"EOF";
-$0 <Revision $VERSION> - tool to generate database specific SQL from the XML database definition files used by OTRS
+$0 - tool to generate database specific SQL from the XML database definition files used by OTRS
 
 Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 
@@ -86,12 +81,8 @@ else {
     push @DatabaseType, $Opts{t};
 }
 
-# read xml file
-my @File       = <STDIN>;
-my $FileString = '';
-for my $Line (@File) {
-    $FileString .= $Line;
-}
+# read xml data from STDIN
+my $FileString = do { local $/; <STDIN> };
 
 for my $DatabaseType (@DatabaseType) {
 
@@ -122,15 +113,10 @@ for my $DatabaseType (@DatabaseType) {
     # parse xml package
     my @XMLARRAY = $CommonObject{XMLObject}->XMLParse( String => $FileString );
 
-    # remember header
-    my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $CommonObject{TimeObject}->SystemTime2Date(
-        SystemTime => $CommonObject{TimeObject}->SystemTime(),
-    );
-
     my $Head = $CommonObject{DBObject}->{Backend}->{'DB::Comment'}
         . "----------------------------------------------------------\n";
     $Head .= $CommonObject{DBObject}->{Backend}->{'DB::Comment'}
-        . " driver: $DatabaseType, generated: $Year-$Month-$Day $Hour:$Min:$Sec\n";
+        . " driver: $DatabaseType\n";
     $Head .= $CommonObject{DBObject}->{Backend}->{'DB::Comment'}
         . "----------------------------------------------------------\n";
 
@@ -183,8 +169,10 @@ sub Dump {
     my ( $Filename, $SQL, $Head, $Commit, $StdOut ) = @_;
 
     if ($StdOut) {
+        ## no critic
         open my $OutHandle, '>', $Filename or die "Can't write: $!";
         binmode $OutHandle, ':utf8';
+        ## use critic
         print "writing: $Filename\n";
         print $OutHandle $Head;
         for my $Item ( @{$SQL} ) {
