@@ -2,8 +2,6 @@
 // Core.Form.Validate.js - provides functions for validating form inputs
 // Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.Form.Validate.js,v 1.34.2.6 2012/10/20 15:16:02 ep Exp $
-// --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
 // did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
@@ -56,15 +54,18 @@ Core.Form.Validate = (function (TargetNS) {
         return;
     }
 
+    if (!Core.Debug.CheckDependency('Core.Form.Validate', 'Core.App', 'Core.App')) {
+        return;
+    }
+
     /**
      * @function
-     * @private
      * @param {jQueryObject} $Element The jQuery object of the form  or any element
      * @param {String} ErrorType The error type (a class that identify the error type)
      * @return nothing
      * @description Show initialize the tooltips
      */
-    function HighlightError(Element, ErrorType) {
+    TargetNS.HighlightError = function (Element, ErrorType) {
         var $Element = $(Element),
             InputErrorMessageHTML,
             InputErrorMessageText;
@@ -91,7 +92,7 @@ Core.Form.Validate = (function (TargetNS) {
         // if the field has a servererror class and the value was not changed,
         // keep the error class.
         if ($Element.is('input:checkbox, input:radio')) {
-            $Element.data('ValidateOldValue', $Element.attr('checked'));
+            $Element.data('ValidateOldValue', $Element.prop('checked'));
         }
         else {
             $Element.data('ValidateOldValue', $Element.val());
@@ -99,12 +100,12 @@ Core.Form.Validate = (function (TargetNS) {
 
         // Get the target element and find the associated hidden div with the
         // error message.
-        InputErrorMessageHTML = $(Core.App.EscapeSelector('#' + $Element.attr('id') + ErrorType)).html();
-        InputErrorMessageText = $(Core.App.EscapeSelector('#' + $Element.attr('id') + ErrorType)).text();
+        InputErrorMessageHTML = $('#' + Core.App.EscapeSelector($Element.attr('id')) + ErrorType).html();
+        InputErrorMessageText = $('#' + Core.App.EscapeSelector($Element.attr('id')) + ErrorType).text();
 
         if (InputErrorMessageHTML && InputErrorMessageHTML.length) {
             // if error field is a RTE, it is a little bit more difficult
-            if ($('#cke_' + Element.id).length) {
+            if ($('#cke_' + Core.App.EscapeSelector(Element.id)).length) {
                 Core.Form.ErrorTooltips.InitRTETooltip($Element, InputErrorMessageHTML);
             } else {
                 Core.Form.ErrorTooltips.InitTooltip($Element, InputErrorMessageHTML);
@@ -120,16 +121,15 @@ Core.Form.Validate = (function (TargetNS) {
                 $Element.focus();
             }, 0);
         }
-    }
+    };
 
     /**
      * @function
-     * @private
      * @param {Object} Element The object of the form  or any element within this form that should be serialized
      * @return nothing
      * @description Remove error classes from element and its label
      */
-    function UnHighlightError(Element) {
+    TargetNS.UnHighlightError = function (Element) {
         var $Element = $(Element),
             ElementValue,
             RemoveError = true;
@@ -138,7 +138,7 @@ Core.Form.Validate = (function (TargetNS) {
         // if the field value has not changed, do not remove error class
         if ($Element.hasClass(Options.ServerErrorClass)) {
             if ($Element.is('input:checkbox, input:radio')) {
-                ElementValue = $Element.attr('checked');
+                ElementValue = $Element.prop('checked');
             }
             else {
                 ElementValue = $Element.val();
@@ -161,13 +161,13 @@ Core.Form.Validate = (function (TargetNS) {
             $Element.attr('aria-invalid', false);
 
             // if error field is a RTE, it is a little bit more difficult
-            if ($('#cke_' + Element.id).length) {
+            if ($('#cke_' + Core.App.EscapeSelector(Element.id)).length) {
                 Core.Form.ErrorTooltips.RemoveRTETooltip($Element);
             } else {
                 Core.Form.ErrorTooltips.RemoveTooltip($Element);
             }
         }
-    }
+    };
 
     /**
      * @function
@@ -221,10 +221,13 @@ Core.Form.Validate = (function (TargetNS) {
             return (Text.length && Text !== '-');
         }
 
-        // for rich text areas, update the linked field for the validation first
+        // for richtextareas, get editor code and remove all tags and whitespace
+        // keep tags if images are embedded because of inline-images
         if (Core.UI.RichTextEditor.IsEnabled($Element)) {
-            CKEDITOR.instances[$Element.attr('id')].updateElement();
-            Value = $Element.val();
+            Value = CKEDITOR.instances[Element.id].getData();
+            if (!Value.match(/<img/)) {
+                Value = Value.replace(/\s+|&nbsp;|<\/?\w+[^>]*\/?>/g, '');
+            }
         }
 
         // checkable inputs
@@ -254,7 +257,7 @@ Core.Form.Validate = (function (TargetNS) {
         // JS takes new lines '\n\r' in textarea elements as 1 character '\n' for length
         // calculation purposes therefore is needed to re-add the '\r' to get the correct length
         // for validation and match to perl and database criteria
-        return ( Value.replace(/\n\r?/g, "\n\r").length <= $(Element).attr('maxlength') );
+        return ( Value.replace(/\n\r?/g, "\n\r").length <= $(Element).data('maxlength') );
     }, "");
 
     $.validator.addMethod("Validate_DateYear", function (Value, Element) {
@@ -501,8 +504,8 @@ Core.Form.Validate = (function (TargetNS) {
             $(this).validate({
                 ignoreTitle: true,
                 errorClass: Options.ErrorClass,
-                highlight: HighlightError,
-                unhighlight: UnHighlightError,
+                highlight: TargetNS.HighlightError,
+                unhighlight: TargetNS.UnHighlightError,
                 errorPlacement: OnErrorElement,
                 submitHandler: OnSubmit,
                 ignore: '.' + Options.IgnoreClass
@@ -519,7 +522,10 @@ Core.Form.Validate = (function (TargetNS) {
 
         if ($ServerErrors.length) {
             $ServerErrors.each(function () {
-                HighlightError(this, 'ServerError');
+                // Show fields with errors that might be in a collapsed box.
+                $(this).parents('.WidgetSimple.Collapsed').toggleClass('Collapsed Expanded');
+                // Highlight error fields.
+                TargetNS.HighlightError(this, 'ServerError');
             });
 
             // When the dialog closes, focus the first element which had a server error
